@@ -27,11 +27,11 @@ from django.forms.utils import flatatt
 from django.forms import widgets
 from django.template.loader import get_template
 from django import urls
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.functional import Promise
 from django.utils import html
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 ip_allowed_symbols_re = re.compile(r'^[a-fA-F0-9:/\.]+$')
 IPv4 = 1
@@ -89,7 +89,11 @@ class IPField(fields.Field):
 
         try:
             if self.mask:
-                self.ip = netaddr.IPNetwork(value)
+                try:
+                    self.ip = netaddr.IPNetwork(value.strip())
+                except netaddr.AddrFormatError:
+                    self.ip = netaddr.IPNetwork(
+                        netaddr.cidr_abbrev_to_verbose(value.strip()))
             else:
                 self.ip = netaddr.IPAddress(value)
         except Exception:
@@ -242,7 +246,7 @@ class SelectWidget(widgets.Widget):
         return attrs
 
     def render_option(self, selected_choices, option_value, option_label):
-        option_value = force_text(option_value)
+        option_value = force_str(option_value)
         other_html = (' selected="selected"'
                       if option_value in selected_choices else '')
 
@@ -259,12 +263,12 @@ class SelectWidget(widgets.Widget):
 
     def render_options(self, selected_choices):
         # Normalize to strings.
-        selected_choices = set(force_text(v) for v in selected_choices)
+        selected_choices = set(force_str(v) for v in selected_choices)
         output = []
         for option_value, option_label in self.choices:
             if isinstance(option_label, (list, tuple)):
                 output.append(html.format_html(
-                    '<optgroup label="{}">', force_text(option_value)))
+                    '<optgroup label="{}">', force_str(option_value)))
                 for option in option_label:
                     output.append(
                         self.render_option(selected_choices, *option))
@@ -279,8 +283,7 @@ class SelectWidget(widgets.Widget):
         if not isinstance(option_label, (str, Promise)):
             for data_attr in self.data_attrs:
                 data_value = html.conditional_escape(
-                    force_text(getattr(option_label,
-                                       data_attr, "")))
+                    force_str(getattr(option_label, data_attr, "")))
                 other_html.append('data-%s="%s"' % (data_attr, data_value))
         return ' '.join(other_html)
 
@@ -288,7 +291,7 @@ class SelectWidget(widgets.Widget):
         if (not isinstance(option_label, (str, Promise)) and
                 callable(self.transform)):
             option_label = self.transform(option_label)
-        return html.conditional_escape(force_text(option_label))
+        return html.conditional_escape(force_str(option_label))
 
     def transform_option_html_attrs(self, option_label):
         if not callable(self.transform_html_attrs):
@@ -308,6 +311,8 @@ class ThemableSelectWidget(SelectWidget):
 
         new_choices = []
         initial_value = value
+        # Initially assuming value is not present in choices.
+        value_in_choices = False
         for opt_value, opt_label in itertools.chain(self.choices, choices):
             other_html = self.transform_option_html_attrs(opt_label)
 
@@ -318,15 +323,19 @@ class ThemableSelectWidget(SelectWidget):
             opt_label = self.transform_option_label(opt_label)
 
             # If value exists, save off its label for use
+            # and setting value in choices to True
             if opt_value == value:
                 initial_value = opt_label
+                value_in_choices = True
 
             if other_html:
                 new_choices.append((opt_value, opt_label, other_html))
             else:
                 new_choices.append((opt_value, opt_label))
 
-        if value is None and new_choices:
+        # if value is None or it is not present in choices then set
+        # the first value of choices.
+        if (value is None or not value_in_choices) and new_choices:
             initial_value = new_choices[0][1]
 
         attrs = self.build_attrs(attrs)
@@ -467,8 +476,8 @@ class ChoiceInput(SubWidget):
         self.name = name
         self.value = value
         self.attrs = attrs
-        self.choice_value = force_text(choice[0])
-        self.choice_label = force_text(choice[1])
+        self.choice_value = force_str(choice[0])
+        self.choice_label = force_str(choice[1])
         self.index = index
         if 'id' in self.attrs:
             self.attrs['id'] += "_%d" % self.index
@@ -523,7 +532,7 @@ class ThemableCheckboxChoiceInput(ChoiceInput):
         super().__init__(*args, **kwargs)
         # NOTE(e0ne): Django sets default value to None
         if self.value:
-            self.value = set(force_text(v) for v in self.value)
+            self.value = set(force_str(v) for v in self.value)
 
     def is_checked(self):
         if self.value:
@@ -583,7 +592,7 @@ class ThemableCheckboxSelectMultiple(widgets.CheckboxSelectMultiple):
                     self.name, self.value, self.attrs.copy(), choice, i)
                 output.append(html.format_html(
                     self.inner_html,
-                    choice_value=force_text(w),
+                    choice_value=force_str(w),
                     sub_widgets=''))
         return html.format_html(
             self.outer_html,
